# Part 2: Main program flow

We want to solve a shallow water flow problem in a rough
channel to obtain the water table and
compare it to the analytic solution. This is done with the
`main()` function
of the program which is defined in the file `main.cc` described below.

The code documentation is structured as follows:

[[_TOC_]]

